@@ -500,6 +500,13 @@ void endPathWithSlash(string &path,bool requireOSSlash) {
 	}
 }
 
+string formatPath(string path) {
+  replaceAll(path, "\"", "");
+  replaceAll(path, "//", "/");
+
+  return path;
+}
+
 void trimPathWithStartingSlash(string &path) {
 	if(StartsWith(path, "/") == true || StartsWith(path, "\\") == true) {
 		path.erase(path.begin(),path.begin()+1);
@@ -1587,6 +1594,11 @@ bool changeVideoMode(int resW, int resH, int colorBits, int ) {
 
 void restoreVideoMode(bool exitingApp) {
     //SDL_Quit();
+	if(exitingApp == true && SDL_WasInit(SDL_INIT_VIDEO)) {
+		SDL_ShowCursor(1);
+		SDL_WM_GrabInput(SDL_GRAB_OFF);
+		SDL_SetGamma(1, 1, 1);
+	}
 }
 
 int getScreenW() {
